@@ -48,3 +48,47 @@ sub uri {
 1;
 __END__
 
+=head1 NAME
+
+Catalyst::Plugin::Session::Client::Rewrite - handle sessonid with rewriting URL
+
+=head1 SYNOPSIS
+
+    use Catalyst qw/Session::Manager/;
+
+    MyApp->config->{session} = {
+        client => 'Rewrite',
+        name   => 'SESSIONID',
+    };
+
+=head1 DESCRIPTION
+
+This module allows you to handle sessionid with rewriting URL.
+
+=head1 CONFIGURATION
+
+=over 4
+
+=item name
+
+'SESSIONID' is set by default.
+
+=back
+
+=head1 SEE ALSO
+
+L<Catalyst>
+
+L<Catalyst::Plugin::Session::Manager>
+
+=head1 AUTHOR
+
+Lyo Kato E<lt>lyo.kato@gmail.comE<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+=cut
+
